==> igloo_0_1_2.zip: igloo_0_1_2/igloo/language/1/barnraiser_01/frm_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'frm_view.lang.php');

$lang['hdr_update'] = 							"update";

//HEADER
$lang['hdr_subject'] = 							"subject";
$lang['hdr_edit_topic'] =						"edit topic";
$lang['hdr_topics'] =							"topics";


// HREF
$lang['href_add_item'] = 						"ADD";


// FORM
$lang['form_label_title'] = 					"Title";
$lang['form_body'] = 							"details";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_rsp_group'] = 						"Check to submit this to the web site editor for inclusion on the group home page.";
$lang['form_rsp_node'] = 						"Check to submit this to the node editor for inclusion in Splash.";
$lang['form_rsp_group_auto'] = 					"Check to add this to the group home page.";
$lang['form_rsp_node_auto'] = 					"Check to add this to Splash.";
$lang['form_submit_delete'] = 					"DELETE";
$lang['form_label_topic_order'] = 				"order";
$lang['form_just_me'] = 						"just me";
$lang['form_label_synopsis'] = 					"synopsis";


// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_item_edit'] = 						"Sorry, you are not allowed to edit this item.";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_header_3'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the blog on all lists. Choose one from the list below if desired.";
$lang['txt_header_1'] = 						"1. Subject overview";
$lang['txt_overview_intro'] = 					"You can add a discussion subject to this community. Be short and make sure you ask a question.";
$lang['txt_header_2'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add your subject.";
$lang['sub_check_spelling'] = 					"check spelling";
$lang['txt_none'] = 							"none";
$lang['txt_header_4'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this subject to be published to.";
$lang['txt_header_5'] = 						"6. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_topic_intro'] = 						"Below is a list of topics that are available to the community.";
$lang['txt_topic_edit_intro'] = 				"You can add or edit a topic.";
$lang['txt_topic_title'] = 						"topic title";
$lang['txt_topic_synopsis'] = 					"topic synopsis";
$lang['txt_topic_roles'] = 						"Which roles can add a new subject under this topics?";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_locked'] = 							"locked";
$lang['txt_sticky'] = 							"sticky";

$lang['txt_publish_node_help'] =				"Submit to 'Stuff' editor";
$lang['txt_publish_auto_node_help'] = 			"Stuff";

$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"public web site";

?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/frm_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'frm_view.lang.php');

$lang['hdr_update'] = 							"update";

//HEADER
$lang['hdr_subject'] = 							"add or edit a subject";
$lang['hdr_edit_topic'] =						"add or edit a topic";
$lang['hdr_topics'] =							"topics";


// HREF
$lang['href_add_item'] = 						"ADD";


// FORM
$lang['form_label_title'] = 					"Title";
$lang['form_body'] = 							"details";
$lang['form_label_preview'] = 					"preview";
$lang['form_label_file'] = 						"thumbnail image";
$lang['form_label_topic_order'] = 				"order";
$lang['form_just_me'] = 						"Just me";
$lang['form_label_synopsis'] = 					"synopsis";
$lang['form_public'] = 							"Public web site";
$lang['form_label_track'] = 					"Send me an email when a comment is received";


// ERR
$lang['err_no_topics'] = 						"Sorry, there are no topics to display.";
$lang['err_item_edit'] = 						"Sorry, you are not allowed to edit this item.";


//BODY TEXT
$lang['txt_topic'] = 							"topic";
$lang['txt_header_3'] = 						"4. Thumbnail image";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the blog on all lists. Choose one from the list below if desired.";
$lang['txt_header_1'] = 						"1. Subject overview";
$lang['txt_overview_intro'] = 					"You can add a discussion subject to this community. Be short and make sure you ask a question.";
$lang['txt_header_2'] = 						"3. Details";
$lang['txt_detail_intro'] = 					"Add your subject.";
$lang['txt_none'] = 							"none";
$lang['txt_header_4'] = 						"5. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this subject to be published to.";
$lang['txt_header_5'] = 						"7. Save";
$lang['txt_save_intro'] = 						"Save your work. 'save and go' will take you to the details page.";
$lang['txt_topic_intro'] = 						"Below is a list of topics that are available to the community.";
$lang['txt_topic_edit_intro'] = 				"You can add or edit a topic.";
$lang['txt_topic_title'] = 						"topic title";
$lang['txt_topic_synopsis'] = 					"topic synopsis";
$lang['txt_topic_roles'] = 						"Which roles can add a new subject under this topics?";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_locked'] = 							"locked";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_publish_node_help'] =				"Submit to 'Group' editor for inclusion in the featured page";
$lang['txt_publish_auto_node_help'] = 			"Include in the 'Group' featured page";
$lang['txt_publish_public_help'] =				"Submit to public web site editor";
$lang['txt_publish_auto_public_help'] =			"Include in the public web site";
$lang['txt_degree_nw'] = 						"My network only";
$lang['txt_publish_all'] = 						"Everyone in our group";
$lang['txt_header_7'] = 						"6. Feedback";

?>
